@@ -592,30 +592,28 @@ return 0;
 void cre_align_opt_menu(SEA_VIEW *view, Fl_Menu_Button *obj, props_menu_parts *parts)
 {
 char msa_name[60], *name; 
-int elt, attr, count;
+int elt, attr;
 
 obj->add("Alignment options", 0, 0, 0, FL_SUBMENU);
-count = int_res_value("msa_algo_count", 0);
 for(elt = 1; elt <= MAX_MSA_ALGOS; elt++) {
 	sprintf(msa_name, "Alignment options/hidden_%d", elt);
 	attr = FL_MENU_RADIO; 
-	if(elt == count) attr |= FL_MENU_DIVIDER;
-	if(elt > count) attr |= FL_MENU_INVISIBLE;
+	if(elt == view->count_msa_algos) attr |= FL_MENU_DIVIDER;
+	if(elt > view->count_msa_algos) attr |= FL_MENU_INVISIBLE;
 	attr = obj->add(msa_name, 0, align_opt_callback, parts, attr);
 	if(elt == 1) parts->clustalopt = attr;
-	if(elt <= count) {
+	if(elt <= view->count_msa_algos) {
 		sprintf(msa_name, "msa_name_%d", elt);
 		name = get_res_value(msa_name, NULL);
 		obj->replace(parts->clustalopt + elt - 1, name );
+#ifndef WIN32
 		if(get_full_path(name) == NULL) {
 			attr = obj->mode(parts->clustalopt + elt - 1);
 			obj->mode(parts->clustalopt + elt - 1, attr | FL_MENU_INACTIVE);
-			}
+			} 
+#endif
 		}
 	}
-view->count_msa_algos = count;
-elt = int_res_value("alignment", 1);
-view->alignment_algorithm = (elt < count ? elt : 1);
 ((Fl_Menu_Item *)obj->menu() + parts->clustalopt + view->alignment_algorithm)->set();
 name = get_algo_opts(view->alignment_algorithm, NULL);
 sprintf(msa_name, "Alignment options/%s", name == NULL ? "<none>" : name);
