@@ -166,10 +166,10 @@ int my_system_macho(char *command, char *base_fname)
 {
 char comfile[300];
 FILE *out;
-FSRef myref, myterm, frontproc;
-LSLaunchFSRefSpec mylaunch;
+FSRef myref, myterm;
 OSStatus status;
 ProcessSerialNumber newpsn, mypsn;
+Boolean cankill;
 
 sprintf(comfile, "%s.command", base_fname);
 out = fopen(comfile, "w");
@@ -178,24 +178,43 @@ fclose(out);
 chmod(comfile, S_IRUSR|S_IXUSR);
 status = FSPathMakeRef((const UInt8 *)comfile, &myref, NULL);
 LSFindApplicationForInfo(kLSUnknownCreator, CFSTR("com.apple.terminal"), NULL, &myterm, NULL);
-mylaunch.appRef = &myterm; // FSRef to the Terminal application
-mylaunch.numDocs = 1;
-mylaunch.itemRefs = &myref;
-mylaunch.passThruParams = NULL;
-mylaunch.launchFlags =  kLSLaunchNewInstance ; // run a new Terminal instance
-mylaunch.asyncRefCon = NULL;
-status = LSOpenFromRefSpec(&mylaunch, &frontproc); // frontproc becomes FSRef to newly started Terminal
-if(status == noErr) {
+GetCurrentProcess(&mypsn); // seaview
+if(LSOpenItemsWithRole == NULL) { // before MacOSX 10.4
+	LSLaunchFSRefSpec mylaunch;
+	Boolean compare;
+	FSRef frontproc;
+	mylaunch.appRef = &myterm; // FSRef to the Terminal application
+	mylaunch.numDocs = 1;
+	mylaunch.itemRefs = &myref;
+	mylaunch.passThruParams = NULL;
+	mylaunch.launchFlags =  kLSLaunchNewInstance ; // run a new Terminal instance
+	mylaunch.asyncRefCon = NULL;
+	status = LSOpenFromRefSpec(&mylaunch, &frontproc); // frontproc becomes FSRef to newly started Terminal
 	GetFrontProcess(&newpsn); // the newly started Terminal
-	GetCurrentProcess(&mypsn); // seaview
+	SameProcess(&newpsn, &mypsn, &compare);
+	// try to kill only a newly started Terminal and not something else nor seaview
+	cankill = FSCompareFSRefs(&frontproc, &myterm) == noErr && !compare;
+	}
+else {
+	LSApplicationParameters mylsap;
+	mylsap.version = 0;
+	mylsap.flags = kLSLaunchNewInstance;
+	mylsap.application = &myterm;
+	mylsap.asyncLaunchRefCon = NULL;
+	mylsap.environment = NULL;
+	mylsap.argv = NULL;
+	mylsap.initialEvent = NULL;
+	status = LSOpenItemsWithRole(&myref, 1, kLSRolesAll, NULL, &mylsap, &newpsn, 1);
+	cankill = TRUE;
+	}
+if(status == noErr) {
     sleep(2);
 	fl_cursor(FL_CURSOR_DEFAULT, FL_BLACK, FL_BLACK);
 	SetFrontProcess(&mypsn);
 	status = fl_choice(
 		"Wait for alignment completion in Terminal window.",
 		"Ignore or interrupt alignment", "Alignment completed", NULL) ? 0 : 1 ; 
-	// try to kill only a newly started Terminal and not something else
-	if( FSCompareFSRefs(&frontproc, &myterm) == noErr) KillProcess(&newpsn);
+	if( cankill) KillProcess(&newpsn);
 	}
 unlink(comfile);
 return status != noErr;
@@ -407,7 +426,7 @@ item.user_data_ = data;
 
 
 extern Fl_Sys_Menu_Bar *fl_sys_menu_bar;
-void cre_sys_menu(Fl_Callback *newwindow_callback, void *data)
+void cre_sys_menu(void)
 {
 static const Fl_Menu_Item items[] = {
 	{"Window", 0, NULL, 0, FL_SUBMENU} ,
