@@ -20,7 +20,7 @@ int save_fasta_file(const char *fname, char **seq, char **comments,
 	int *sel_seqs, int tot_sel_seqs);
 int save_phylip_file(const char *fname, char **seq,
 	char **seqname, int totseqs, int *eachlength, region *region_used, 
-	int *sel_seqs, int tot_sel_seqs);
+	int *sel_seqs, int tot_sel_seqs, int phylipwidnames);
 int output_next_res_from_region(char *seq, int lenseq, 
 	list_segments **segment, int *current, FILE *out, int total, 
 	int use_dots);
@@ -43,7 +43,7 @@ char *save_alignment_or_region(const char *fname, char **seq, char **comments,
 	list_regions *regions, region *region_used, known_format format,
 	int numb_species_sets, int **list_species_sets, 
 	char **name_species_sets, int *sel_seqs, int tot_sel_seqs, int protein,
-	int tot_comment_lines, char **comment_name, char **comment_line);
+	int tot_comment_lines, char **comment_name, char **comment_line, int phylipwidnames);
 int prepare_printout(const char *filename, char **seq, int totseqs,  
 	char **seqname,
 	int *eachlength, int char_per_line,
@@ -348,7 +348,7 @@ int read_phylip_align(const char *fname, char ***pseq, char ***pseqname,
 		char ***pcomments, char **pheader, char **err_message)
 {
 FILE *in;
-char *p, *q, line[PHYNAME + 200];
+char *p, *q, line[300];
 char **seq, **comments, **seqname;
 int totseqs, lenseqs, i, l;
 static char ret_message[200];
@@ -373,13 +373,14 @@ comments = (char **)malloc(totseqs * sizeof(char *));
 if(comments == NULL) goto nomem;
 for(i=0; i<totseqs; i++) {
 	if( (seq[i] = (char *)malloc(lenseqs+1) ) == NULL ) goto nomem;
-	if( (seqname[i] = (char *)malloc(PHYNAME+1) ) == NULL ) goto nomem;
 	comments[i] = NULL;
 	}
 for(i=0; i<totseqs; i++) {
 	fgets(line,sizeof(line),in);
-	memcpy(seqname[i],line,PHYNAME); seqname[i][PHYNAME] = 0;
-	p = line+PHYNAME; q = seq[i];
+	p = strstr(line + 10, " "); if(p == NULL) p = line + 10;
+	if( (seqname[i] = (char *)malloc(p - line + 1) ) == NULL ) goto nomem;
+	memcpy(seqname[i], line, p - line); seqname[i][p - line] = 0;
+	q = seq[i];
 	while(*p != '\n') {
 		if(*p != ' ') *(q++) = *p;
 		p++;
@@ -619,7 +620,7 @@ int is_a_protein_seq(char *seq)
 static char dna[]="ACGTU";
 int total=0, length=0;
 while(*seq != 0) {
-	if(*seq != '-' && toupper(*seq) != 'N') { 
+	if(*seq != '-' && *seq != '?' && toupper(*seq) != 'N') { 
 		if( strchr(dna, toupper(*seq)) != NULL ) total++;
 		length++; 
 		}
@@ -631,7 +632,7 @@ return ( (float)(total) / length ) <= 0.8 ;
 
 int save_phylip_file(const char *fname, char **seq,
 	char **seqname, int totseqs, int *eachlength, region *region_used, 
-	int *sel_seqs, int tot_sel_seqs)
+	int *sel_seqs, int tot_sel_seqs, int phylipwidnames)
 /* sauver des sequences ou des regions au format phylip
 region_used pointe vers la region a sauver
 si region_used == NULL, toutes les sequences sont sauvees
@@ -642,7 +643,7 @@ rend 0 si ok,
 {
 const int widphylin = 60;
 FILE *out;
-int lenseqs, i, j, retval = 1, current, save_current, err, vtotseqs, lu;
+int lenseqs, i, j, retval = 1, current, save_current, err, vtotseqs, lu, maxlname;
 list_segments *psegment, all_sequence, *curr_segment;
 region maregion;
 
@@ -666,18 +667,25 @@ while(psegment != NULL) {
 	lenseqs += psegment->fin - psegment->debut + 1;
 	psegment = psegment->next;
 	}
+/* longest seq name */
 vtotseqs = 0;
-for(i=0; i < totseqs; i++) 
-	if(tot_sel_seqs == 0 || sel_seqs[i]) ++vtotseqs;
+maxlname = 0;
+for(i=0; i < totseqs; i++) {
+	if(tot_sel_seqs == 0 || sel_seqs[i]) {
+		++vtotseqs;
+		if( (j = strlen(seqname[i])) > maxlname) maxlname = j;
+		}
+	}
+if(maxlname > phylipwidnames) maxlname = phylipwidnames;
 fprintf(out,"%d   %d\n", vtotseqs, lenseqs);
 for(i=0; i < totseqs; i++) {
 	if(tot_sel_seqs != 0 && ! sel_seqs[i]) continue;
 	psegment = region_used->list; current = 0;
-	for(j = 0; j < PHYNAME; j++) {
+	for(j = 0; j < maxlname; j++) {
 		if(seqname[i][j] == 0) break;
 		putc(seqname[i][j],out);
 		}
-	while(j < PHYNAME) { putc( ' ', out ); j++; }
+	while(j <= maxlname) { putc( ' ', out ); j++; }
 	lu = 0;
 	while(lu < widphylin && psegment != NULL) {
 		putc( ' ', out );
@@ -694,7 +702,7 @@ while( psegment != NULL ) {
 	for(i=0; i < totseqs; i++) {
 		if(tot_sel_seqs != 0 && ! sel_seqs[i]) continue;
 		psegment = curr_segment; current = save_current;
-		for(j = 0; j < PHYNAME; j++) putc( ' ', out );
+		for(j = 0; j <= maxlname; j++) putc( ' ', out );
 		lu = 0;
 		while(lu < widphylin && psegment != NULL) {
 			putc( ' ', out );
@@ -1155,7 +1163,7 @@ char *save_alignment_or_region(const char *fname, char **seq, char **comments,
 	list_regions *regions, region *region_used, known_format format,
 	int numb_species_sets, int **list_species_sets, 
 	char **name_species_sets, int *sel_seqs, int tot_sel_seqs, int protein,
-	int tot_comment_lines, char **comment_name, char **comment_line)
+	int tot_comment_lines, char **comment_name, char **comment_line, int phylipwidnames)
 /* sauver des sequences ou des regions au format de fichier format
 region_used pointe vers la liste des regions a sauver
 si region_used == NULL, toutes les sequences entieres sont sauvees
@@ -1181,7 +1189,7 @@ else if(format == NEXUS_FORMAT)
 else if(format == PHYLIP_FORMAT) 
 	err = save_phylip_file(fname, seq,
 		seqname, totseqs, eachlength, region_used, 
-		sel_seqs, tot_sel_seqs);
+		sel_seqs, tot_sel_seqs, phylipwidnames);
 else if(format == CLUSTAL_FORMAT) 
 	err = save_clustal_file(fname, seq,
 		seqname, totseqs, eachlength, region_used, 
